==> image-data-domain-0.0.96-sources.jar: com/xforceplus/elephant/entity/Ticket.java <==
package com.xforceplus.elephant.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-07-01
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class Ticket implements Serializable {

  private static final long serialVersionUID=1L;

  private Long imageId;

  private String billCode;

  private String batchNo;

  private String warningStatus;

  private String warningInfo;

  private String exceptionStatus;

  private String exceptionInfo;

  private String checkStatus;

  private String checkRemark;

  private String checkTaskId;

  private LocalDateTime checkRequestTime;

  private LocalDateTime checkResponseTime;

  private Long checkUserId;

  private String checkUserName;

  private String isHooked;

  private Long xPoint;

  private Long yPoint;

  private Long width;

  private Long height;

  private Long angle;

  private String ticketCode;

  private BigDecimal amountWithoutTax;

  private BigDecimal taxAmount;

  private BigDecimal amountWithTax;

  private Long id;

  private Long tenantId;

  private LocalDateTime createTime;

  private LocalDateTime updateTime;

  private Long createUserId;

  private Long updateUserId;

  private String createUserName;

  private String updateUserName;

  private String deleteFlag;

  private String isPublic;

  private String extFields;

  private String isReuse;

  private String ticketStatus;

  private String reserved1;

  private String reserved2;

  private String reserved3;

  private String isRepeat;

  private String repeatTag;

  private String createUserCode;

  private String systemOrig;

  private String billEntityCode;

  private String reuseTag;

  private String tenantCode;

  private String backStatus;

  private LocalDateTime backTime;

  private Long scanUserId;

  private String scanUserName;

  private String isSalesList;

  private String calculateStatus;

  private String relWarningInfo;

  private String relExceptionInfo;

  private Long ticketManyToOneImageId;




        }

==> image-data-domain-0.0.124-sources.jar: com/xforceplus/elephant/entity/Ticket.java <==
package com.xforceplus.elephant.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-07-31
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class Ticket implements Serializable {

  private static final long serialVersionUID=1L;

  private Long imageId;

  private String billCode;

  private String batchNo;

  private String warningStatus;

  private String warningInfo;

  private String exceptionStatus;

  private String exceptionInfo;

  private String checkStatus;

  private String checkRemark;

  private String checkTaskId;

  private LocalDateTime checkRequestTime;

  private LocalDateTime checkResponseTime;

  private Long checkUserId;

  private String checkUserName;

  private String isHooked;

  private Long xPoint;

  private Long yPoint;

  private Long width;

  private Long height;

  private Long angle;

  private String ticketCode;

  private BigDecimal amountWithoutTax;

  private BigDecimal taxAmount;

  private BigDecimal amountWithTax;

  private Long id;

  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  @TableField(fill = FieldFill.INSERT)
  private LocalDateTime createTime;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private LocalDateTime updateTime;

  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  private String isPublic;

  private String extFields;

  private String isReuse;

  private String ticketStatus;

  private String reserved1;

  private String reserved2;

  private String reserved3;

  private String isRepeat;

  private String repeatTag;

  private String createUserCode;

  private String systemOrig;

  private String billEntityCode;

  private String reuseTag;

  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  private String backStatus;

  private LocalDateTime backTime;

  private Long scanUserId;

  private String scanUserName;

  private String isSalesList;

  private String calculateStatus;

  private String relWarningInfo;

  private String relExceptionInfo;

  private Long ticketManyToOneImageId;




        }
